# Changelog

## [0.2.1a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.2.1a1) (2024-10-15)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.2.0...0.2.1a1)

**Merged pull requests:**

- requirements:latest stable packages [\#563](https://github.com/OpenVoiceOS/ovos-core/pull/563) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
